@@ -220,6 +220,22 @@ class WordPressManager {
             }
         }
         
+        // Create wp-cli.yml file to enable mod_rewrite (required for .htaccess generation)
+        $wpCliYmlContent = "apache_modules:\n  - mod_rewrite\n";
+        $wpCliYmlPath = $path . '/wp-cli.yml';
+        
+        // Write wp-cli.yml file inside container
+        $createYmlCmd = "echo " . escapeshellarg($wpCliYmlContent) . " > " . escapeshellarg($wpCliYmlPath);
+        $dockerCmd = "docker exec --user " . escapeshellarg($data['user']) . " -w " . escapeshellarg($path) . " " . 
+                    escapeshellarg($data['container']) . " /bin/bash -c " . escapeshellarg($createYmlCmd);
+        
+        exec($dockerCmd . " 2>&1", $output, $returnCode);
+        if ($returnCode !== 0) {
+            error_log("Warning: Failed to create wp-cli.yml: " . implode("\n", $output));
+        } else {
+            error_log("Created wp-cli.yml file for mod_rewrite support");
+        }
+        
         // Set up proper permalink structure with .htaccess
         $permalinkCmd = "wp rewrite structure '/%postname%/'";
         $permalinkResult = $this->execWpCli($data['container'], $data['user'], $permalinkCmd, $path);
@@ -227,7 +243,7 @@ class WordPressManager {
             error_log("Warning: Failed to set up permalinks: " . $permalinkResult['output']);
         }
         
-        // Flush rewrite rules to ensure .htaccess is created
+        // Flush rewrite rules to ensure .htaccess is created (now with mod_rewrite enabled)
         $flushCmd = "wp rewrite flush --hard";
         $flushResult = $this->execWpCli($data['container'], $data['user'], $flushCmd, $path);
         if (!$flushResult['success']) {
@@ -759,8 +775,30 @@ Options -Indexes
             throw new Exception("No admin username found for this WordPress site");
         }
         
-        // First, ensure the wp-cli-login-command plugin is installed and activated
-        $installCmd = "wp login install --activate --mu --yes";
+        // Ensure wp-cli.yml exists for mod_rewrite support (required for login plugin)
+        $wpCliYmlContent = "apache_modules:\n  - mod_rewrite\n";
+        $wpCliYmlPath = $path . '/wp-cli.yml';
+        
+        // Check if wp-cli.yml already exists
+        $checkYmlCmd = "test -f " . escapeshellarg($wpCliYmlPath);
+        $checkResult = $this->execWpCli($site['container_name'], $site['user'], $checkYmlCmd, $path);
+        
+        if (!$checkResult['success']) {
+            // wp-cli.yml doesn't exist, create it
+            $createYmlCmd = "echo " . escapeshellarg($wpCliYmlContent) . " > " . escapeshellarg($wpCliYmlPath);
+            $dockerCmd = "docker exec --user " . escapeshellarg($site['user']) . " -w " . escapeshellarg($path) . " " . 
+                        escapeshellarg($site['container_name']) . " /bin/bash -c " . escapeshellarg($createYmlCmd);
+            
+            exec($dockerCmd . " 2>&1", $output, $returnCode);
+            if ($returnCode !== 0) {
+                error_log("Warning: Failed to create wp-cli.yml for auto-login: " . implode("\n", $output));
+            } else {
+                error_log("Created wp-cli.yml file for auto-login mod_rewrite support");
+            }
+        }
+        
+        // First, install the wp-cli-login-command companion plugin
+        $installCmd = "wp login install --mu --yes";
         $installResult = $this->execWpCli($site['container_name'], $site['user'], $installCmd, $path);
         
         // Log the installation attempt for debugging
@@ -770,10 +808,13 @@ Options -Indexes
         $output = $installResult['output'];
         $hasCompanionPlugin = strpos($output, 'Success: Companion plugin installed') !== false;
         $alreadyInstalled = strpos($output, 'already installed') !== false;
-        $alreadyActive = strpos($output, 'already active') !== false;
         
-        // If we don't have the companion plugin and it's not already there, that's a real error
-        if (!$hasCompanionPlugin && !$alreadyInstalled && !$alreadyActive) {
+        if ($hasCompanionPlugin || $alreadyInstalled) {
+            // Plugin is installed, now activate it manually
+            $activateCmd = "wp login toggle on";
+            $activateResult = $this->execWpCli($site['container_name'], $site['user'], $activateCmd, $path);
+            error_log("WP-CLI login plugin activation result: " . $activateResult['output']);
+        } else {
             // Check if the login command itself exists by trying to run it
             $testCmd = "wp login --help";
             $testResult = $this->execWpCli($site['container_name'], $site['user'], $testCmd, $path);
