@@ -474,10 +474,11 @@ class haproxy_manager {
             
             // Get site containers and primary domain, including listen_port_tls
             $stmt = $this->db->prepare("
-                SELECT sc.container_id, sc.container_number, ct.listen_port, ct.listen_port_tls, d.domain_name as primary_domain
+                SELECT sc.container_id, sc.container_number, ct.listen_port, ct.listen_port_tls, COALESCE(sd.fqdn, d.domain_name) as primary_domain
                 FROM whp.site_containers sc
                 JOIN whp.sites s ON sc.site_id = s.id
                 JOIN whp.domains d ON s.primary_domain_id = d.id
+                LEFT JOIN whp.site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
                 JOIN whp.container_types ct ON s.container_type_id = ct.id
                 WHERE sc.site_id = ? AND sc.status = 'running'
             ");
